@@ -1,4 +1,4 @@
-#' Implement significant figure-like rounding for ratios
+#' Style significant figure-like rounding for ratios
 #'
 #' When reporting ratios, such as relative risk or an odds ratio, we'll often
 #' want the rounding to be similar on each side of the number 1.  For example,
@@ -11,6 +11,7 @@
 #' @param digits Integer specifying the number of significant
 #' digits to display for numbers below 1. Numbers larger than 1 will be be `digits + 1`.
 #' Default is `digits = 2`.
+#' @inheritParams style_number
 #' @export
 #' @return A character vector of styled ratios
 #' @family style tools
@@ -21,10 +22,10 @@
 #'   -0.9, -1.1234, -12.345, -101.234
 #' ) %>%
 #'   style_ratio()
-style_ratio <- function(x, digits = 2) {
+style_ratio <- function(x, digits = 2, big.mark = NULL, decimal.mark = NULL, ...) {
   ifelse(
     abs(x) < 1,
-    style_sigfig(x, digits = digits),
-    style_sigfig(x, digits = digits + 1)
+    style_sigfig(x, digits = digits, big.mark = big.mark, decimal.mark = decimal.mark, ...),
+    style_sigfig(x, digits = digits + 1, big.mark = big.mark, decimal.mark = decimal.mark, ...)
   )
 }
