@@ -63,28 +63,3 @@ trial %>%
   bold_p(t = 0.10, q = TRUE) %>%
   bold_labels()
 
-## ---- eval=FALSE--------------------------------------------------------------
-#  help("Rprofile")
-#  
-#  usethis::edit_r_profile()
-
-## ---- echo=FALSE--------------------------------------------------------------
-data.frame(
-  `Description` = c("Formatting and rounding p-values", 
-                    "Formatting and rounding for regression coefficients",
-                    "Set level for limits",
-                    "Print tables with `gt` or `kable`"),
-  `Example` = c("`options(gtsummary.pvalue_fun = function(x) gtsummary::style_pvalue(x, digits = 2))`",
-                '`options(gtsummary.tbl_regression.estimate_fun = function(x) gtsummary::style_sigfig(x, digits = 3))`',
-                '`options(gtsummary.conf.level = 0.90)`',
-                '`options(gtsummary.print_engine = "kable")`   `options(gtsummary.print_engine = "gt")`'),
-  `Functions` = c("`add_p()`, `tbl_regression()`, `tbl_uvregression()`",
-                  "`tbl_regression()`, `tbl_uvregression()`",
-                  "`tbl_regression()`, `tbl_uvregression()`",
-                  "All `tbl_*()` functions")
-) %>% 
-  knitr::kable()
-
-## ----eval=FALSE---------------------------------------------------------------
-#  options(gtsummary.tbl_regression.estimate_fun = function(x) sigfig(x, digits = 3))
-
