@@ -14,7 +14,7 @@ head(trial)
 ## -----------------------------------------------------------------------------
 trial2 =
   trial %>%
-  dplyr::select(trt, marker, stage)
+  select(trt, marker, stage)
 
 ## ---- message=FALSE-----------------------------------------------------------
 tbl_summary(trial2)
@@ -65,7 +65,7 @@ trial2 %>%
 
 ## -----------------------------------------------------------------------------
 trial %>%
-  dplyr::select(trt, response, age, stage, marker, grade) %>%
+  select(trt, response, age, stage, marker, grade) %>%
   tbl_summary(
     by = trt,
     type = list(c(response, grade) ~ "categorical"), # select by variables in c()
@@ -87,25 +87,52 @@ tbl_summary(trial2, by = trt) %>%
   gt::tab_spanner(label = gt::md("**Treatment Group**"),
                   columns = gt::starts_with("stat_"))
 
-## ---- eval=FALSE--------------------------------------------------------------
-#  help("Rprofile")
-#  
-#  usethis::edit_r_profile()
+## -----------------------------------------------------------------------------
+# loading the api data set
+data(api, package = "survey")
 
-## ---- echo=FALSE--------------------------------------------------------------
-data.frame(
-  `Description` = c("Formatting and rounding p-values", 
-                    "Formatting and rounding percentages",
-                    "Print tables with `gt` or `kable`"),
-  `Example` = c("`options(gtsummary.pvalue_fun = function(x) gtsummary::style_pvalue(x, digits = 2))`",
-                '`options(gtsummary.tbl_summary.percent_fun = function(x) sprintf("%.2f", 100 * x))`',
-                '`options(gtsummary.print_engine = "kable")`   `options(gtsummary.print_engine = "gt")`'),
-  `Functions` = c("`add_p()`, `tbl_regression()`, `tbl_uvregression()`",
-                  "`tbl_summary()`",
-                  "All `tbl_*()` functions")
-) %>% 
-  knitr::kable()
+## -----------------------------------------------------------------------------
+svy_apiclus1 <- 
+  survey::svydesign(
+    id = ~dnum, 
+    weights = ~pw, 
+    data = apiclus1, 
+    fpc = ~fpc
+  ) 
 
-## ----eval=FALSE---------------------------------------------------------------
-#  options(gtsummary.tbl_summary.percent_fun = function(x) sigfig(x, digits = 3))
+## -----------------------------------------------------------------------------
+svy_apiclus1 %>%
+  tbl_svysummary(
+    # stratify summary statistics by the "both" column
+    by = both, 
+    # summarize a subset of the columns
+    include = c(cname, api00, api99, both),
+    # adding labels to table
+    label = list(
+      cname ~ "County",
+      api00 ~ "API in 2000",
+      api99 ~ "API in 1999"
+    )
+  ) %>%
+  # comparing values by "both" column
+  add_p() %>%
+  add_overall() %>%
+  # adding spanning header
+  modify_spanning_header(starts_with("stat_") ~ "**Met Both Targets**")
+
+## -----------------------------------------------------------------------------
+d <- dplyr::as_tibble(Titanic)
+head(d, n = 10)
+
+## -----------------------------------------------------------------------------
+d %>%
+  survey::svydesign(data = ., ids = ~ 1, weights = ~ n) %>%
+  tbl_svysummary()
+
+## -----------------------------------------------------------------------------
+trial %>%
+  tbl_cross(row = stage,
+    col = trt,
+    percent = "cell") %>%
+  add_p()
 
